@@ -1,5 +1,13 @@
 from qibo.models import hep, tsp
 from qibo.models.circuit import Circuit
+from qibo.models.error_mitigation import (
+    CDR,
+    ZNE,
+    get_gammas,
+    get_noisy_circuit,
+    sample_training_circuit,
+    vnCDR,
+)
 from qibo.models.evolution import AdiabaticEvolution, StateEvolution
 from qibo.models.grover import Grover
 from qibo.models.qft import QFT
