@@ -1,10 +1,11 @@
-# -*- coding: utf-8 -*-
 """Test methods of :class:`qibo.core.hamiltonians.SymbolicHamiltonian`."""
 import numpy as np
 import pytest
 import sympy
 
-from qibo import hamiltonians
+from qibo import gates, hamiltonians
+from qibo.models import Circuit
+from qibo.symbols import I, Y, Z
 from qibo.tests.utils import random_complex
 
 
@@ -270,6 +271,36 @@ def test_symbolic_hamiltonian_state_ev(
     backend.assert_allclose(local_ev, target_ev)
 
 
+def test_hamiltonian_expectation_from_samples(backend):
+    """Test Hamiltonian expectation value calculation."""
+    obs0 = 2 * Z(0) * Z(1) + Z(0) * Z(2)
+    obs1 = 2 * Z(0) * Z(1) + Z(0) * Z(2) * I(3)
+    h0 = hamiltonians.SymbolicHamiltonian(obs0, backend=backend)
+    h1 = hamiltonians.SymbolicHamiltonian(obs1, backend=backend)
+    c = Circuit(4)
+    c.add(gates.RX(0, np.random.rand()))
+    c.add(gates.RX(1, np.random.rand()))
+    c.add(gates.RX(2, np.random.rand()))
+    c.add(gates.RX(3, np.random.rand()))
+    c.add(gates.M(0, 1, 2, 3))
+    nshots = 10**5
+    result = c(nshots=nshots)
+    freq = result.frequencies(binary=True)
+    Obs0 = h0.expectation_from_samples(freq, qubit_map=None)
+    Obs1 = h1.expectation(result.state())
+    backend.assert_allclose(Obs0, Obs1, atol=10 / np.sqrt(nshots))
+
+
+def test_hamiltonian_expectation_from_samples_errors(backend):
+    obs = [Z(0) * Y(1), Z(0) * Z(1) ** 3]
+    h1 = hamiltonians.SymbolicHamiltonian(obs[0], backend=backend)
+    h2 = hamiltonians.SymbolicHamiltonian(obs[1], backend=backend)
+    with pytest.raises(NotImplementedError):
+        h1.expectation_from_samples(None, qubit_map=None)
+    with pytest.raises(NotImplementedError):
+        h2.expectation_from_samples(None, qubit_map=None)
+
+
 @pytest.mark.parametrize("density_matrix", [False, True])
 @pytest.mark.parametrize("calcterms", [False, True])
 def test_symbolic_hamiltonian_abstract_symbol_ev(backend, density_matrix, calcterms):
